@@ -11,13 +11,14 @@ public enum PageType implements PageID {
 private static final long serialVersionUID = 1L;
 private static volatile java.util.HashMap<Integer,PageType>	map = new java.util.HashMap<Integer,PageType>();
 public static void init() {
+PageLoader	pf = (PageLoader)PageLoader.getPageFactory();
 try {
 Page	page;
-paraselene.supervisor.PageFactory	pf = PageLoader.getPageFactory();
 #3
 pf.start();
 } catch( Exception e ) {
 Option.debug( e );
+pf.failInit();
 }
 }
 
