@@ -75,6 +75,18 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 		this( new SimpleDateFormat( format ).format( date ) );
 	}
 
+	/**
+	 * コンストラクタ。日時を文字列にします。<BR>
+	 * 例えばnew Text(new Date(), &quot;yyyy/MM/dd HH:mm:ss&quot;) は
+	 * &quot;2009/01/01 15:00:00&quot;のような文字列を格納します。
+	 * @param date 日時。
+	 * @param format フォーマット。
+	 * @param locale フォーマットに使用するロケール。
+	 */
+	public Text( Date date, String format, Locale locale ) {
+		this( new SimpleDateFormat( format, locale ).format( date ) );
+	}
+
 	/**
 	 * コンストラクタ。
 	 * @param txt テキスト。
