@@ -272,10 +272,10 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 */
 	public QueryItem[] getQuery() {
 		String	q = super.toString();
-		if ( q == null ) {
-			return new QueryItem[0];
-		}
-		q = q.split( "#" )[0];
+		if ( q == null )	return new QueryItem[0];
+		String[]	fr = q.split( "#" );
+		if ( fr.length == 0 )	return new QueryItem[0];
+		q = fr[0];
 		String[]	pre = q.split( "\\?" );
 		if ( pre.length < 2 )	return new QueryItem[0];
 		String[]	str = pre[1].split( "&" );
