@@ -30,6 +30,15 @@ public class Forward implements Serializable {
 	transient ArrayList<Cookie>	out_cookie = new ArrayList<Cookie>();
 	boolean done_f = false;
 
+	boolean is_refresh() {
+		if ( this instanceof Feedback )	return false;
+		return out_page != null;
+	}
+
+	boolean isRefresh( boolean ajax_f ) {
+		if ( !ajax_f )	return true;
+		return is_refresh();
+	}
 
 	boolean isLeave() {
 		return error > 0 || redirect_uri != null;
