@@ -23,7 +23,7 @@ public class HistorySet implements Serializable {
 	private HashMap<Integer,History>	hist = new HashMap<Integer,History>();
 	private String session_id;
 
-	HistorySet( String sid) {
+	HistorySet( String sid) throws ParaseleneException {
 		session_id = sid;
 		newNo( ROOT );
 	}
@@ -105,12 +105,17 @@ public class HistorySet implements Serializable {
 		Option.trace( "history all drop" );
 	}
 
-	synchronized private int newNo( int no ) {
+	synchronized private int newNo( int no ) throws ParaseleneException {
 		if ( no < 0 )	no *= -1;
+		if ( no == RAND )	no = 1;
+		int	org = no;
 		while ( true ) {
-			if ( no == RAND || hist.get( no ) != null ) {
+			if ( hist.get( no ) != null ) {
 				no++;
-				if ( no < 0 )	no = 1;
+				if ( no < 0 || no == RAND )	no = 1;
+				if ( no == org ) {
+					throw new ParaseleneException( "HistorySet overflow." );
+				}
 				continue;
 			}
 			hist.put( no, new History( no, session_id ) );
@@ -119,19 +124,18 @@ public class HistorySet implements Serializable {
 		}
 	}
 
-	int toInt() {
-		return newNo( (int)new Date().getTime() & 0x7fffffff );
+	int toInt() throws ParaseleneException {
+		return newNo( (int)new Date().getTime() & RAND );
 	}
 
-	synchronized void forceNewNo( int no ) {
+	synchronized void forceNewNo( int no ) throws ParaseleneException {
 		if ( hist.get( no ) != null )	return;
 		newNo( no );
 	}
 
-	synchronized int toInt( String name, int org ) {
+	synchronized int toInt( String name, int org ) throws ParaseleneException {
 		if ( name == null )	return org;
-		if ( name.isEmpty() )	return org;
-		if ( "_self".equals( name ) )	return org;
+		if ( name.isEmpty() || "_self".equals( name ) )	return org;
 		if ( "_top".equals( name ) )	return ROOT;
 		if ( "_blank".equals( name ) || "_parent".equals( name ) ) {
 			return RAND;
@@ -139,7 +143,9 @@ public class HistorySet implements Serializable {
 		if ( name.indexOf( "paraselene" ) >= 0 )	return org;
 		Integer	ret = set_no.get( name );
 		if ( ret != null )	return ret;
-		int	n = newNo( name.hashCode() );
+		int	n = name.hashCode();
+		if ( n == ROOT || n == RAND )	n = 1;
+		n = newNo( n );
 		set_no.put( name, n );
 		return n;
 	}
