@@ -35,19 +35,25 @@ class OutputCall {
 		next_page.setHistoryKey( next_key );
 	}
 
-	void call_main() throws Throwable {
+	void call_main( boolean refresh_f ) throws Throwable {
 		next_page.setRequestParameter( req );
 		Option.trace( "%s/%s output(%s) call", next_page.getID(), next_page.getUniqueKey(), (last_page == null)?	"null": last_page.getID() );
 		data.hist.forceNewNo( next_page.getHistoryKey() );
-		data.hist.get( next_page.getHistoryKey() ).add( next_page );
-		Page	view = SandBox.output( next_page, last_page, req );
+		data.hist.get( next_page.getHistoryKey() ).add( next_page.getParentPage() );
+		Page	view = SandBox.output( next_page, last_page, req, refresh_f );
 		if ( view == null )	view = next_page;
+		next_page.setAgencyPage( view );
 		next_page.setInitialized( false );
 		next_page.setRequestParameter( null );
+		if ( view != next_page ) {
+			view.setAgencyPage( null );
+			view.setInitialized( false );
+			view.setRequestParameter( null );
+		}
 		out = new Page[]{ next_page, view };
 	}
 
-	void call() throws Throwable {
+	void call( boolean refresh_f ) throws Throwable {
 		PageID	last_id = null;
 		if ( last_page != null ) {
 			last_id = last_page.getID();
@@ -70,7 +76,7 @@ class OutputCall {
 				}
 			}
 		}
-		call_main();
+		call_main( refresh_f );
 	}
 
 	static PostBack[] make( History h, Page next_page, Page[] out, boolean lock_f ) throws Exception {
@@ -103,10 +109,10 @@ class OpenOutput extends OutputCall {
 		next_page.setPopupType( type );
 	}
 
-	void call() throws Throwable {
+	void call( boolean refresh_f ) throws Throwable {
 		Popup	p = (Popup)forward;
 		if ( p.active_page != null )	return;
-		call_main();
+		call_main( refresh_f );
 	}
 
 	static PostBack[] make( Popup p, History h, Page next_page, Page out, boolean lock_f  ) throws Exception {
@@ -150,7 +156,7 @@ class CloseOutput extends OutputCall {
 		super( nk, lp, fw, r, sd );
 	}
 
-	void call() throws Throwable {}
+	void call( boolean refresh_f ) throws Throwable {}
 
 	static PostBack[] make( Closure c, History h, Page next_page ) {
 		h.removePopup( c.close_page );
@@ -168,7 +174,7 @@ class ScriptOutput extends OutputCall {
 	ScriptOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		super( nk, lp, fw, r, sd );
 	}
-	void call() throws Throwable {}
+	void call( boolean refresh_f ) throws Throwable {}
 
 	static PostBack[] make( JavaScript js ) throws Exception {
 		StringBuilder	buf = new StringBuilder();
@@ -190,7 +196,7 @@ class NopOutput extends OutputCall {
 	NopOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		super( nk, lp, fw, r, sd );
 	}
-	void call() throws Throwable {}
+	void call( boolean refresh_f ) throws Throwable {}
 
 	static PostBack[] _make() throws Exception {
 		Option.trace( "NOP JSON" );
@@ -207,8 +213,8 @@ class LocationOutput extends OutputCall {
 		super( nk, lp, fw, r, sd );
 	}
 
-	void call() throws Throwable {
-		if ( !forward.isLeave() )	super.call();
+	void call( boolean refresh_f ) throws Throwable {
+		if ( !forward.isLeave() )	super.call( refresh_f );
 	}
 
 	PostBack[] make() throws Exception {
@@ -227,19 +233,23 @@ class LocationOutput extends OutputCall {
 class OutputHolder {
 	private Forward[]		forward = null;
 	private OutputCall[]	opc = null;
+	private boolean[]		refresh_f = null;
 
 	OutputHolder( boolean ajax_f, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		Option.trace( "%s ajax %s", lp.getID(), ajax_f );
 		AjaxForward[]	af = fw.getAjaxForward( ajax_f );
 		if ( af != null ) {
 			forward = new Forward[af.length];
+			refresh_f = new boolean[af.length];
 			for ( int i = 0; i < af.length; i++ ) {
 				forward[i] = (Forward)af[i];
+				refresh_f[i] = forward[i].isRefresh( ajax_f );
 			}
 			opc = new OutputCall[af.length];
 		}
 		else {
 			forward = new Forward[] { fw };
+			refresh_f = new boolean[] { fw.isRefresh( ajax_f ) };
 			opc = new OutputCall[1];
 		}
 		if ( ajax_f ) {
@@ -254,7 +264,7 @@ class OutputHolder {
 
 	void call() throws Throwable {
 		for ( int i = 0; i < opc.length; i++ ) {
-			opc[i].call();
+			opc[i].call( refresh_f[i] );
 		}
 	}
 
