@@ -83,9 +83,10 @@ public abstract class Supervisor extends HttpServlet {
 		super();
 	}
 
-	private static String resolvePage( ServerInformation holder, PageID from_page, String p, int from_key, int to_key ) {
+	private static String resolvePage( ServerInformation holder, Page from, String p, int from_key, int to_key ) {
 		try {
 			URI	u = new URI( p );
+			PageID	from_page = from.getID();
 			PageID	to = null;
 			Page	page = from_page.getPageFactory().getPage(
 				Integer.parseInt( u.getPath().substring( LINK_LEN[0] ) )
@@ -94,6 +95,16 @@ public abstract class Supervisor extends HttpServlet {
 				to = page.getID();
 				to.getPageFactory().returnPage( page );
 			}
+			Page	parent = from.getParentPage();
+			if ( from != parent ) {
+				if ( from_page == to ) {
+					page = parent;
+					from_page = to = parent.getID();
+				}
+				else {
+					from_page = parent.getID();
+				}
+			}
 			if ( to != null ) {
 				StringBuilder	path = new StringBuilder(
 					TransactionSequencer.makeURI(
@@ -225,7 +236,7 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			switch( def_no ) {
 			case 0:
-				part[i] = resolvePage( holder, page.getID(), part[i], from_key, to_key );
+				part[i] = resolvePage( holder, page, part[i], from_key, to_key );
 				break;
 			case 1:
 			case 2:
@@ -551,6 +562,7 @@ public abstract class Supervisor extends HttpServlet {
 				}
 				Page	do_page = last_page.reflect( req );
 				if ( do_page == null && !(last_page instanceof NullPage) && req.getItemCount() > 0 ) {
+					Option.trace( "reflect -> IllegalRequest.DISAPPROVAL_REQUEST" );
 					fw = onIllegalRequest( IllegalRequest.DISAPPROVAL_REQUEST, req, last_page, next_page );
 					if ( fw != null ) {
 						session_f = fw.session_clear_f;
@@ -566,6 +578,9 @@ public abstract class Supervisor extends HttpServlet {
 				else if ( do_page != null && do_page != last_page ) {
 					last_page = do_page;
 				}
+				if ( last_page.getID() != null ) {
+					Option.trace( String.format( "reflect -> %s(%s)", last_page.getID().toString(), last_page.getUniqueKey() ) );
+				}
 				last_page.setRequestParameter( req );
 				if ( next_page != null ) {
 					if ( from_key != to_key ) {
@@ -611,7 +626,7 @@ public abstract class Supervisor extends HttpServlet {
 			if ( path_data.to_histry != null ) {
 				out_hist_key = path_data.to_histry;
 			}
-			OutputHolder	oh = new OutputHolder( ajax != null && last_page.isAjax(), out_hist_key, last_page, fw, req, data );
+			OutputHolder	oh = new OutputHolder( ajax != null && last_page.getParentPage().isAjax(), out_hist_key, last_page, fw, req, data );
 			oh.call();
 			String	key = last_page.getUniqueKey();
 			ajax = req.getItem( A_AJAX_KEY );
