@@ -64,6 +64,7 @@ public class Tag extends HTMLPart {
 	 */
 	public void setAjaxEnable( boolean flag ) {
 		ajax_f = flag;
+		setModify();
 	}
 
 	/**
@@ -85,11 +86,14 @@ public class Tag extends HTMLPart {
 
 	private boolean modify_enable = true;
 
-	private void set_modify() {
+	/**
+	 * フレームワークが使用します。
+	 */
+	protected void setModifyMyselef() {
 		if ( getAttribute( "id" ) == null ) {
 			Tag	out = getOuterTag();
 			if ( out != null ) {
-				out.set_modify();
+				out.setModifyMyselef();
 				return;
 			}
 		}
@@ -103,10 +107,17 @@ public class Tag extends HTMLPart {
 		if ( !modify_enable )	return;
 		Tag	out = getOuterTag();
 		if ( out != null ) {
-			out.set_modify();
+			out.setModifyMyselef();
 			return;
 		}
-		set_modify();
+		setModifyMyselef();
+	}
+
+	/**
+	 * フレームワークが使用します。
+	 */
+	public boolean isModified() {
+		return dirty_f;
 	}
 
 	/**
@@ -123,7 +134,10 @@ public class Tag extends HTMLPart {
 		modify_enable = flag;
 	}
 
-	void getModifiedTag( ArrayList<Tag> list ) {
+	/**
+	 * フレームワークが使用します。
+	 */
+	protected void getModifiedTag( ArrayList<Tag> list ) {
 		if ( dirty_f ) {
 			list.add( this );
 			return;
@@ -731,7 +745,7 @@ public class Tag extends HTMLPart {
 	 */
 	public void include( Page page, boolean move_f ) {
 		if ( page == null )	return;
-		include( page.getFirstTagByType( "body" ), move_f );
+		include( page.getBodyTag(), move_f );
 	}
 
 	/**
@@ -909,8 +923,8 @@ public class Tag extends HTMLPart {
 	 * @param mode 文字列種別。
 	 */
 	public void write( PrintWriter w, StringMode mode ) {
-		dirty_f = false;
 		if ( !visible_f )	return;
+		dirty_f = false;
 		w.print( "\r\n" );
 		w.print( getFirstTag() );
 		int	cnt = getHTMLPartCount();
@@ -1268,7 +1282,7 @@ public class Tag extends HTMLPart {
 		Page	page = getAssignedPage();
 		String	id = makeID();
 		StringBuilder	buf = new StringBuilder();
-		buf = buf.append( "paraselene_safe_add_event('" );
+		buf = buf.append( "paraselene.safe_add_event('" );
 		buf = buf.append( id );
 		buf = buf.append( "','" );
 		buf = buf.append( triger );
